@@ -9,21 +9,28 @@ use overload
 
 use Data::Transformer;
 use Scalar::Util qw( blessed );
+use Types::Standard qw( Int );
+use Type::Utils qw( declare as where inline_as coerce from );
 use namespace::sweep;
 
+my $PositiveInt = declare
+    as Int,
+    where { $_ >= 0 },
+    inline_as {"$_ =~ /^[0-9]\$/ and $_ >= 0"};
+
+coerce $PositiveInt, from Int, q{ abs $_ };
+
 has default_field => ( is => 'rw' );
 has parser        => ( is => 'ro' );
 has debug         => (
-    is  => 'rw',
-    isa => sub {
-        if ( defined( $_[0] ) and $_[0] =~ m/\D/ ) {
-            confess "$_[0] should be an int";
-        }
-    },
-    default => sub { $ENV{PERL_DEBUG} || 0 }
+    is      => 'rw',
+    isa     => $PositiveInt,
+    coerce  => $PositiveInt->coercion,
+    lazy    => 1,
+    builder => sub { $ENV{PERL_DEBUG} || 0 }
 );
 
-our $VERSION = '0.301';
+our $VERSION = '0.302';
 
 =head1 NAME
 
@@ -344,7 +351,6 @@ sub get_field {
             confess "invalid field name: $name";
         }
         my $field_class = $self->field_class;
-        carp "field_class=$field_class";
         $field = $field_class->new( name => $name );
     }
     return $field;
